translate.storage.ts

Package translate :: Package storage :: Module ts |
[hide private]
[frames] | no frames]

# Module ts

source code

Module for parsing Qt .ts files for translation.

Currently this module supports the old format of .ts files. Some applictaions use the newer .ts format which are documented here: TS file format 4.3, Example

Specification of the valid variable entries, 2

Classes | [hide private]
| QtTsParser

Imports: ourdom